BOOK_GROUPS | pythonbible
Description: `BOOK_GROUPS` is a provided "constant" containing the default dictionary of book groups to be used when allowing book groups to be considered when getting all of the references contained within a text.

Skip to main content

# BOOK_GROUPS

`BOOK_GROUPS` is a provided "constant" containing the default dictionary of book groups to be used when allowing book groups to be considered when getting all of the references contained within a text.

For each entry in this dictionary, the key is the regular expression string associated with the given book group, and the value is the list of `Book` objects associated with the given book group.

The following book groups are included: